@@ -14,6 +14,7 @@ from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSPercentileSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis import TechnicalAnalysis
 from PyFin.Analysis.transformer import transform
@@ -27,6 +28,7 @@ __all__ = ['DataProvider',
            'CSAverageAdjustedSecurityValueHolder',
            'CSQuantileSecurityValueHolder',
            'CSZScoreSecurityValueHolder',
+           'CSPercentileSecurityValueHolder',
            'SecurityLatestValueHolder',
            'TechnicalAnalysis',
            'transform']
