@@ -10,6 +10,7 @@ from PyFin.api.DateUtilities import bizDatesList
 from PyFin.api.DateUtilities import holDatesList
 from PyFin.api.DateUtilities import advanceDate
 from PyFin.api.DateUtilities import BizDayConventions
+from PyFin.api.DateUtilities import DateGeneration
 from PyFin.api.DateUtilities import isBizDay
 from PyFin.api.DateUtilities import adjustDateByCalendar
 from PyFin.api.DateUtilities import advanceDateByCalendar
@@ -56,11 +57,14 @@ from PyFin.api.Analysis import ASINH
 from PyFin.api.Analysis import SHIFT
 from PyFin.api.Analysis import IIF
 from PyFin.api.Analysis import RES
+from PyFin.api.Analysis import CORR
+from PyFin.api.Analysis import RANK
 
 from PyFin.api.Analysis import CSRank
 from PyFin.api.Analysis import CSMean
 from PyFin.api.Analysis import CSMeanAdjusted
-from PyFin.api.Analysis import CSQuantile
+from PyFin.api.Analysis import CSQuantiles
+from PyFin.api.Analysis import CSPercentile
 from PyFin.api.Analysis import CSZScore
 
 from PyFin.Utilities.Asserts import pyFinAssert
@@ -72,6 +76,7 @@ __all__ = ["datesList",
            "isBizDay",
            "advanceDate",
            "BizDayConventions",
+           "DateGeneration",
            "adjustDateByCalendar",
            "advanceDateByCalendar",
            "nthWeekDay",
@@ -114,11 +119,14 @@ __all__ = ["datesList",
            "ASIN",
            "ASINH",
            "RES",
+           "CORR",
+           "RANK",
            "SHIFT",
            "IIF",
            "CSRank",
            "CSMean",
            "CSMeanAdjusted",
-           "CSQuantile",
+           "CSQuantiles",
            "CSZScore",
+           "CSPercentile",
            "pyFinAssert"]
